<?php
/**
*  @author		@mario forum.prestashop.pl 2012
*  @license		http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
*/

if (!defined('_PS_VERSION_'))
	exit;

	
class IP4Location extends Module
{
	private $hook = 'beforeInit';
	
	public function __construct()
	{
		$this->name = 'ip4location';
		$this->tab = 'front_office_features';
		$this->version = '1.0';
		$this->author = '@mario forum.prestashop.pl';
		$this->need_instance = 0;
		
		parent::__construct();
		$this->displayName = 'IP4Location';
		$this->description = $this->l('Prestashop default lang and currency changer to country visitor.');
		$this->confirmUninstall = $this->l('Are you sure that you want to uninstall IP4Location module?');
		if (!$this->_checkBeforeInit())
				$this->warning = $this->l('Please read information in module first!');
	}
	
	
	public function install()
	{
		// Install SQL
		include(dirname(__FILE__).'/sql-install.php');
		foreach ($sql as $s)
			if (!Db::getInstance()->Execute($s))
					return false;

		// Install hook
		if(!Hook::get($this->hook))
			if (!Db::getInstance()->AutoExecute(_DB_PREFIX_.'hook', array('name' => $this->hook, 'title' => 'On before Init in Controllers', 'description' => 'Get exec modules before FrontController init', 'position' => 0), 'INSERT'))
					return false;

		// Install Module
		if (parent::install()
			AND $this->registerHook($this->hook))
				return true;
		return false;
	}
	
	
	public function uninstall()
	{
		if (parent::uninstall()
			AND Db::getInstance()->Execute('DROP TABLE `'._DB_PREFIX_.'ip4location`'))
				return true;
		return false;
	}
	
		
	public function hookBeforeInit()
	{
		$iparray = array();
		if (isset ($_COOKIE[md5('ps')]))
				return;

		// For Webbot protection, e.g. google - some bots working on Gecko engine ( no check Gecko )
		if (strpos($_SERVER["HTTP_USER_AGENT"], 'Mozilla') === false 
		&& strpos($_SERVER['HTTP_USER_AGENT'], 'Apple') === false
		&& strpos($_SERVER['HTTP_USER_AGENT'], 'Safari') === false
		&& strpos($_SERVER['HTTP_USER_AGENT'], 'MSIE') === false 
		&& strpos($_SERVER['HTTP_USER_AGENT'], 'Chrome') === false)
				return;

		$iparray = explode('.', $_SERVER["REMOTE_ADDR"]);
		//$iparray = explode('.', '81.98.88.223'); // for testing - localization England
		$ipaddr = (int)$iparray[3] + (int)$iparray[2]*256 + (int)$iparray[1]*256*256 + (int)$iparray[0]*256*256*256;
		$result = Db::getInstance()->getRow('
					SELECT l.id_lang as lang, c.id_currency as currency
					FROM '._DB_PREFIX_.'ip4location i
					JOIN '._DB_PREFIX_.'lang l ON ( UPPER( l.iso_code ) = i.lang )
					JOIN '._DB_PREFIX_.'currency c ON ( UPPER( c.iso_code ) = i.currency )
					WHERE c.active = 1
					AND c.deleted = 0
					AND l.active = 1
					AND i.ip_from <= '.$ipaddr.'
					AND i.ip_to >= '.$ipaddr);

		if ($result && intval($result['lang']))
				Configuration::set('PS_LANG_DEFAULT', intval($result['lang']));
		if ($result && intval($result['currency']))
				Configuration::set('PS_CURRENCY_DEFAULT', intval($result['currency']));
	}

	
	private function _checkBeforeInit()
	{
		$instance = new FrontController();
		return method_exists($instance, '_'.$this->hook);
	}
	

	public function getContent()
	{
		$this->_html = '<h2>'.$this->displayName.'</h2>';
		$this->_html .= '
		<b>'.$this->l('This module allows to switch the default language and currency ( if installed ) according to the country visitor.').'</b><br />';
		$this->_html .= $this->l('Search Bots transparently.<br />');
		if (!$this->_checkBeforeInit())
			$this->_html .= '<h2><p style="color:red">'.$this->l('You need copy FrontController.php from module directory to the override/classes/</p></h2><br />');
	
		return $this->_html;
	}
}
?>
